==> owncloud_8.0.16.orig.tar.gz: owncloud/apps/activity/l10n/ja.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "アクティビティ",
    "Your settings have been updated." : "設定を更新しました。",
    "A file or folder has been <strong>shared</strong>" : "ファイルまたはフォルダーを<strong>共有</strong>したとき",
    "A new file or folder has been <strong>created</strong>" : "新しいファイルまたはフォルダーを<strong>作成</strong>したとき",
    "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーを<strong>変更</strong>したとき",
    "A file or folder has been <strong>deleted</strong>" : "ファイルまたはフォルダーを<strong>削除</strong>したとき",
    "A file or folder has been <strong>restored</strong>" : "ファイルまたはフォルダーを <strong>復元</strong>したとき",
    "You created %1$s" : "あなたは %1$s を作成しました",
    "%2$s created %1$s" : "%2$s は%1$s を作成しました",
    "%1$s was created in a public folder" : "公開フォルダーに %1$s が作成されました",
    "You changed %1$s" : "あなたは %1$s を変更しました",
    "%2$s changed %1$s" : "%2$s は%1$s を変更しました",
    "You deleted %1$s" : "あなたは %1$s を削除しました",
    "%2$s deleted %1$s" : "%2$s は %1$s を削除しました",
    "You restored %1$s" : "%1$s を復元しました",
    "%2$s restored %1$s" : "%2$s は、 %1$s を復元しました",
    "You shared %1$s with %2$s" : "あなたは %1$s を %2$s と共有しました",
    "You shared %1$s with group %2$s" : "あなたは %1$s をグループ %2$s と共有しました",
    "%2$s shared %1$s with you" : "%2$s は %1$s をあなたと共有しました",
    "You shared %1$s via link" : "リンク経由で %1$s を共有しています",
    "Activity notification" : "アクティビティ通知",
    "All Activities" : "すべてのアクティビティ",
    "Activities by you" : "あなたのアクティビティ",
    "Activities by others" : "他人のアクティビティ",
    "Shares" : "共有",
    "Files" : "ファイル",
    "\"remote user\"" : "\"リモートユーザー\"",
    "in %s" : "%s で",
    "%s and %s" : "%s と %s",
    ", " : ", ",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["%s と <strong class=\"tooltip\" title=\"%s\">それ以外に %n 個</strong>"],
    "%s and %n more::%s and %n more" : ["%s と それ以外に %n 個"],
    "Hello %s," : "%s さんこんにちは、",
    "You are receiving this email because in the last hour the following things happened at %s" : "このメールは、最近１時間に %s で以下の事象が発生したことをお知らせするものです。",
    "You are receiving this email because in the last day the following things happened at %s" : "このメールは、最近１日間に %s で以下の事象が発生したことをお知らせするものです。",
    "You are receiving this email because in the last week the following things happened at %s" : "このメールは、最近１週間に %s で以下の事象が発生したことをお知らせするものです。",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "You will see a list of events here when you start to use your %s." : "%s の使用を開始すると、ここでイベントリストを見ることができます。",
    "No more events to load" : "これ以上読み込むイベントはありません",
    "Enable RSS feed" : "RSSフィードを有効にする",
    "Notifications" : "通知",
    "Mail" : "メール",
    "Stream" : "ストリーム",
    "List your own actions in the stream" : "ストリーム上にあなたの活動を表示",
    "Notify about your own actions via email" : "メールで自身のアクションを通知する",
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取る前にメールアドレスを設定してください。",
    "Send emails:" : "メールを送信:",
    "Hourly" : "1時間ごと",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Activity feed" : "アクティビティフィード",
    "Personal activity feed for %s" : "\"%s\" の個人アクティビティフィード"
},
"nplurals=1; plural=0;");

==> owncloud_8.1.12.orig.tar.gz: owncloud/apps/activity/l10n/ja.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "アクティビティ",
    "Personal activity feed for %s" : "\"%s\" の個人アクティビティフィード",
    "Your feed URL is invalid" : "フィードURLが無効です",
    "Your settings have been updated." : "設定を更新しました。",
    "This stream will show events like additions, changes & shares" : "このタイムラインには、追加、変更、共有が表示されます。",
    "There are no events for this filter" : "このフィルターで表示されるイベントはありません。",
    "Activity notification" : "アクティビティ通知",
    "All Activities" : "すべてのアクティビティ",
    "Activities by you" : "あなたのアクティビティ",
    "Activities by others" : "他人のアクティビティ",
    "\"remote user\"" : "\"リモートユーザー\"",
    "in %s" : "%s で",
    "%s and %s" : "%s と %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s と <strong class=\"tooltip\" title=\"%s\">それ以外に %n 個</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s と それ以外に %n 個"],
    "Hello %s," : "%s さんこんにちは、",
    "You are receiving this email because in the last hour the following things happened at %s" : "このメールは、最近１時間に %s で以下の事象が発生したことをお知らせするものです。",
    "You are receiving this email because in the last day the following things happened at %s" : "このメールは、最近１日間に %s で以下の事象が発生したことをお知らせするものです。",
    "You are receiving this email because in the last week the following things happened at %s" : "このメールは、最近１週間に %s で以下の事象が発生したことをお知らせするものです。",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* と %n 以上 "],
    "Notifications" : "通知",
    "Mail" : "メール",
    "Stream" : "ストリーム",
    "List your own actions in the stream" : "ストリーム上にあなたの活動を表示",
    "Notify about your own actions via email" : "メールで自分のアクションを通知する",
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取る前にメールアドレスを設定してください。",
    "Send emails:" : "メールを送信:",
    "Hourly" : "1時間ごと",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Activity feed" : "アクティビティフィード",
    "Enable RSS feed" : "RSSフィードを有効にする",
    "No activity yet" : "活動状況無し。",
    "No more events to load" : "これ以上読み込むイベントはありません",
    "Files" : "ファイル"
},
"nplurals=1; plural=0;");
